@@ -1,11 +1,10 @@
 from typing_extensions import TypeVar, Callable, Generic, TypedDict
-from haskellian import Either, Left, Right
 from kv import InvalidData
 
 T = TypeVar('T')
 
-Parse = Callable[[bytes], Either[InvalidData, T]]
-Dump = Callable[[T], str|bytes]
+Parse = Callable[[bytes], T]
+Dump = Callable[[T], bytes]
 
 class Serializers(TypedDict, Generic[T]):
   parse: Parse[T]
@@ -14,10 +13,10 @@ class Serializers(TypedDict, Generic[T]):
 class default(Generic[T]):
   """Default, dummy serializers"""
   @staticmethod
-  def parse(data: bytes) -> Either[InvalidData, T]:
-    return Right(data) # type: ignore
+  def parse(data: bytes) -> T:
+    return data # type: ignore
   @staticmethod
-  def dump(value: T) -> str|bytes:
+  def dump(value: T) -> bytes:
     return value # type: ignore
   
   serializers = Serializers(parse=parse, dump=dump)
@@ -30,11 +29,11 @@ def serializers(type: type[T]) -> Serializers[T]:
 
   def parse(data: bytes):
     try:
-      return Right(Root.model_validate_json(data).root)
+      return Root.model_validate_json(data).root
     except ValidationError as e:
-      return Left(InvalidData(str(e)))
+      raise InvalidData(str(e)) from e
     
   def dump(value: T):
-    return Root(value).model_dump_json(exclude_none=True)
+    return Root(value).model_dump_json(exclude_none=True).encode()
   
   return Serializers(parse=parse, dump=dump)
\ No newline at end of file
